==> custom_pages-v1.12.9.zip: custom_pages/messages/sv/base.php <==
<?php

return [
    '<strong>Add</strong> {templateName} item' => '<strong>Lägg till</strong> {templateName} objekt',
    '<strong>Custom</strong> Pages' => '<strong>Anpassade</strong> sidor',
    '<strong>Edit</strong> snippet' => '<strong>Ändra</strong> snippet',
    'Add' => 'Lägg till',
    'Add a file icon before the title' => 'Lägg till en filikon innan titeln',
    'Additional IFrame Attributes' => 'Ytterligare IFrame-attribut',
    'Adds plain HTML content to your site.' => 'Lägger till vanligt HTML-innehåll till din webbplats.',
    'Advanced' => 'Avancerat',
    'Allows the user to manage custom pages.' => 'Låter användaren använda anpassade sidor.',
    'Allows to add pages (markdown, iframe or links) to the space navigation' => 'Tillåter att lägga till sidor (markdown, iframe eller länkar) till forumets navigering',
    'Allows you to add content in MarkDown syntax.' => 'Tillåter dig att lägga till innehåll i MarkDown syntaxen.',
    'Alternate text' => 'Alternativtext',
    'Always make a backup of your view files outside of your production environment!' => 'Gör alltid en backup av dina vyfiler utanför din produktionsmiljö!',
    'An empty allowed template selection will allow all container templates for this container.' => 'Om fältet tillåtna mallval lämnas tomt, tillåts alla mallar för den här behållaren.',
    'Back' => 'Tillbaka',
    'Back to dashboard' => 'Tillbaka till översiktspanelen',
    'Back to overview' => 'Tillbaka till översikt',
    'Back to space' => 'Tillbaka till forum',
    'Can manage custom pages' => 'Kan hantera anpassade sidor',
    'Cannot delete!' => 'Kan inte radera!',
    'Category' => 'Kategori',
    'Configuration' => 'Inställningar',
    'Content' => 'Innehåll',
    'Create' => 'Skapa',
    'Css Class' => 'Css-klass',
    'Custom' => 'Anpassad',
    'Custom Pages' => 'Anpassade sidor',
    'Custom pages' => 'Anpassade sidor',
    'Dashboard' => 'Översiktspanel',
    'Default' => 'Standard',
    'Default Content' => 'Standardinnehåll',
    'Delete' => 'Radera',
    'Deleted.' => 'Raderad.',
    'Edit' => 'Ändra',
    'Edit Page' => 'Ändra sida',
    'Empty' => 'Tom',
    'Empty content elements cannot be deleted!' => 'Tomma innehållselement kan inte raderas!',
    'File' => 'Fil',
    'Footer menu' => 'Sidfotsmeny',
    'General' => 'Allmän',
    'Global Page' => 'Global sida',
    'Global Widget' => 'Global widget',
    'Html' => 'Html',
    'ID' => 'ID',
    'Icon' => 'Ikon',
    'Iframe' => 'Iframe',
    'Insert' => 'Infoga',
    'Invalid request data!' => 'Ogiltig dataförfrågan!',
    'Invalid template selection!' => 'Ogiltigt mallval!',
    'Invalid type selection' => 'Ogiltigt typval',
    'Invalid view file selection!' => 'Ogiltigt val för filgranskning!',
    'Link' => 'Länk',
    'MarkDown' => 'MarkDown',
    'Menu settings' => 'Menyinställningar',
    'Navigation' => 'Navigation',
    'On this page you can configure general settings of your custom pages.' => 'På den här sidan kan du ändra generella inställningar för dina anpassade sidor.',
    'Overview' => 'Översikt',
    'PHP' => 'PHP',
    'Page' => 'Sida',
    'Page Content' => 'Sidans innehåll',
    'Pages' => 'Sidor',
    'Panel' => 'Panel',
    'People Buttons' => 'Knapp för Personer',
    'Please choose one of the following content types. The content type defines how your content is embedded to your site.' => 'Välj en av följande innehållstyper. Innehållstypen definierar hur ditt innehåll bäddas in på webbplatsen.',
    'Please keep in mind that php based pages are vulnerable to security issues, especially when handling user input. For more information, please have a look at <a href="{url}">Yii\'s Security best practices</a>.' => 'Kom i håg att php-baserade sidor är känsliga för säkerhetsrisker, särskilt när det handlar om input från användare. För mer information, se <a href="{url}">Yii\'s Security best practices</a>.',
    'Public' => 'Publik',
    'Reset' => 'Återställ',
    'Reset the content to default value' => 'Återställ innehållet till standardvärdet',
    'Select this setting for visible text nodes only. Uncheck this setting in case this element is used for example as HTML attribute value.' => 'Välj denna inställning endast för synliga textnoder. Avmarkera inställningen om detta element till exempel används  som ett HTML attributvärde.',
    'Settings' => 'Inställningar',
    'Show additional file information (size)' => 'Visa utökad filinformation (storlek)',
    'Snippet' => 'Snippet',
    'Snippets' => 'Snippets',
    'Sort Order' => 'Sorteringsordning',
    'Source' => 'Källa',
    'Space' => 'Forum',
    'Space Members only' => 'Endast forummedlemmar',
    'Space Navigation' => 'Områdesnavigering',
    'Space Page' => 'Forumsida',
    'Space Widget' => 'Forumwidget',
    'Spaces' => 'Forum',
    'Stream' => 'Flöde',
    'Stream options' => 'Alternativ för flöde',
    'Style' => 'Stil',
    'Style Class' => 'Stilklass',
    'Submit' => 'Skicka',
    'Target Url' => 'Mål URL',
    'Template' => 'Mall',
    'Template Layout' => 'Mall layout',
    'Templates' => 'Mallar',
    'Templates allow you to define combinable page fragments with inline edit functionality.' => 'Mallar låter dig definiera kombinerbara sidofragment med inbyggd redigeringsfunktionalitet.',
    'This container does not allow any further items!' => 'Den här behållaren tillåter inga ytterligare föremål!',
    'Title' => 'Titel',
    'Top Navigation' => 'Toppnavigering',
    'Topics' => 'Ämnen',
    'Type' => 'Typ',
    'Upload image' => 'Ladda upp bild',
    'Usage' => 'Användande',
    'User Account Menu (Settings)' => 'Användares kontomeny (inställningar)',
    'Visibility' => 'Synlighet',
    'Will embed the result of a given url as an iframe element.' => 'Kommer bädda in resultatet från en given url som ett iframe-element.',
    'Will redirect requests to a given (relative or absolute) url.' => 'Kommer omdirigera förfrågningar till en given (relativ eller absolut) url.',
    'With PHP based pages you can create custom pages by means of view files in your file system. Please check the module configuration for more Information.' => 'Med PHP-baserade sidor kan du skapa anpassade sidor via vyfiler i ditt filsystem. Gå till modulkonfigurationen för mer information.',
    'Without adding to navigation (Direct link)' => 'Utan att lägga till i navigeringen (direktlänk)',
    'Wrap this HTML page with white panel' => 'Omgärda denna HTML-sida med en vit panel',
    'You are not allowed to delete default content!' => 'Du får inte ta bort standardinnehåll!',
    'Administrative Users' => '',
    'Always' => '',
    'Authors' => '',
    'Container' => '',
    'Content filters' => '',
    'Enter post content ID' => '',
    'Go Back' => '',
    'Import' => '',
    'Layout' => '',
    'Leave empty to list all records related to the current user.' => '',
    'Limit' => '',
    'Logged-In Users' => '',
    'Manage layouts, snippet layouts, and containers. Layouts define page structures, snippet layouts are used in sidebars or sections, and containers are reusable content blocks.' => '',
    'Non-Logged-In Users' => '',
    'Resources' => '',
    'Restrict to following comma separated content IDs' => '',
    'Start Page' => '',
];

==> custom_pages-v1.12.14.zip: custom_pages/messages/sv/base.php <==
<?php

return [
    '<strong>Add</strong> {templateName} item' => '<strong>Lägg till</strong> {templateName} objekt',
    '<strong>Custom</strong> Pages' => '<strong>Anpassade</strong> sidor',
    '<strong>Edit</strong> snippet' => '<strong>Ändra</strong> snippet',
    'Add' => 'Lägg till',
    'Add a file icon before the title' => 'Lägg till en filikon innan titeln',
    'Additional IFrame Attributes' => 'Ytterligare IFrame-attribut',
    'Adds plain HTML content to your site.' => 'Lägger till vanligt HTML-innehåll till din webbplats.',
    'Advanced' => 'Avancerat',
    'Allows the user to manage custom pages.' => 'Låter användaren använda anpassade sidor.',
    'Allows to add pages (markdown, iframe or links) to the space navigation' => 'Tillåter att lägga till sidor (markdown, iframe eller länkar) till forumets navigering',
    'Allows you to add content in MarkDown syntax.' => 'Tillåter dig att lägga till innehåll i MarkDown syntaxen.',
    'Alternate text' => 'Alternativtext',
    'Always make a backup of your view files outside of your production environment!' => 'Gör alltid en backup av dina vyfiler utanför din produktionsmiljö!',
    'An empty allowed template selection will allow all container templates for this container.' => 'Om fältet tillåtna mallval lämnas tomt, tillåts alla mallar för den här behållaren.',
    'Back' => 'Tillbaka',
    'Back to dashboard' => 'Tillbaka till översiktspanelen',
    'Back to overview' => 'Tillbaka till översikt',
    'Back to space' => 'Tillbaka till forum',
    'Can manage custom pages' => 'Kan hantera anpassade sidor',
    'Cannot delete!' => 'Kan inte radera!',
    'Category' => 'Kategori',
    'Configuration' => 'Inställningar',
    'Content' => 'Innehåll',
    'Create' => 'Skapa',
    'Css Class' => 'Css-klass',
    'Custom' => 'Anpassad',
    'Custom Pages' => 'Anpassade sidor',
    'Custom pages' => 'Anpassade sidor',
    'Dashboard' => 'Översiktspanel',
    'Default' => 'Standard',
    'Default Content' => 'Standardinnehåll',
    'Delete' => 'Radera',
    'Deleted.' => 'Raderad.',
    'Edit' => 'Ändra',
    'Edit Page' => 'Ändra sida',
    'Empty' => 'Tom',
    'Empty content elements cannot be deleted!' => 'Tomma innehållselement kan inte raderas!',
    'File' => 'Fil',
    'Footer menu' => 'Sidfotsmeny',
    'General' => 'Allmän',
    'Global Page' => 'Global sida',
    'Global Widget' => 'Global widget',
    'Html' => 'Html',
    'ID' => 'ID',
    'Icon' => 'Ikon',
    'Iframe' => 'Iframe',
    'Insert' => 'Infoga',
    'Invalid request data!' => 'Ogiltig dataförfrågan!',
    'Invalid template selection!' => 'Ogiltigt mallval!',
    'Invalid type selection' => 'Ogiltigt typval',
    'Invalid view file selection!' => 'Ogiltigt val för filgranskning!',
    'Link' => 'Länk',
    'MarkDown' => 'MarkDown',
    'Menu settings' => 'Menyinställningar',
    'Navigation' => 'Navigation',
    'On this page you can configure general settings of your custom pages.' => 'På den här sidan kan du ändra generella inställningar för dina anpassade sidor.',
    'Overview' => 'Översikt',
    'PHP' => 'PHP',
    'Page' => 'Sida',
    'Page Content' => 'Sidans innehåll',
    'Pages' => 'Sidor',
    'Panel' => 'Panel',
    'People Buttons' => 'Knapp för Personer',
    'Please choose one of the following content types. The content type defines how your content is embedded to your site.' => 'Välj en av följande innehållstyper. Innehållstypen definierar hur ditt innehåll bäddas in på webbplatsen.',
    'Please keep in mind that php based pages are vulnerable to security issues, especially when handling user input. For more information, please have a look at <a href="{url}">Yii\'s Security best practices</a>.' => 'Kom i håg att php-baserade sidor är känsliga för säkerhetsrisker, särskilt när det handlar om input från användare. För mer information, se <a href="{url}">Yii\'s Security best practices</a>.',
    'Public' => 'Publik',
    'Reset' => 'Återställ',
    'Reset the content to default value' => 'Återställ innehållet till standardvärdet',
    'Select this setting for visible text nodes only. Uncheck this setting in case this element is used for example as HTML attribute value.' => 'Välj denna inställning endast för synliga textnoder. Avmarkera inställningen om detta element till exempel används  som ett HTML attributvärde.',
    'Settings' => 'Inställningar',
    'Show additional file information (size)' => 'Visa utökad filinformation (storlek)',
    'Snippet' => 'Snippet',
    'Snippets' => 'Snippets',
    'Sort Order' => 'Sorteringsordning',
    'Source' => 'Källa',
    'Space' => 'Forum',
    'Space Members only' => 'Endast forummedlemmar',
    'Space Navigation' => 'Områdesnavigering',
    'Space Page' => 'Forumsida',
    'Space Widget' => 'Forumwidget',
    'Spaces' => 'Forum',
    'Stream' => 'Flöde',
    'Stream options' => 'Alternativ för flöde',
    'Style' => 'Stil',
    'Style Class' => 'Stilklass',
    'Submit' => 'Skicka',
    'Target Url' => 'Mål URL',
    'Template' => 'Mall',
    'Template Layout' => 'Mall layout',
    'Templates' => 'Mallar',
    'Templates allow you to define combinable page fragments with inline edit functionality.' => 'Mallar låter dig definiera kombinerbara sidofragment med inbyggd redigeringsfunktionalitet.',
    'This container does not allow any further items!' => 'Den här behållaren tillåter inga ytterligare föremål!',
    'Title' => 'Titel',
    'Top Navigation' => 'Toppnavigering',
    'Topics' => 'Ämnen',
    'Type' => 'Typ',
    'Upload image' => 'Ladda upp bild',
    'Usage' => 'Användande',
    'User Account Menu (Settings)' => 'Användares kontomeny (inställningar)',
    'Visibility' => 'Synlighet',
    'Will embed the result of a given url as an iframe element.' => 'Kommer bädda in resultatet från en given url som ett iframe-element.',
    'Will redirect requests to a given (relative or absolute) url.' => 'Kommer omdirigera förfrågningar till en given (relativ eller absolut) url.',
    'With PHP based pages you can create custom pages by means of view files in your file system. Please check the module configuration for more Information.' => 'Med PHP-baserade sidor kan du skapa anpassade sidor via vyfiler i ditt filsystem. Gå till modulkonfigurationen för mer information.',
    'Without adding to navigation (Direct link)' => 'Utan att lägga till i navigeringen (direktlänk)',
    'Wrap this HTML page with white panel' => 'Omgärda denna HTML-sida med en vit panel',
    'You are not allowed to delete default content!' => 'Du får inte ta bort standardinnehåll!',
    'Activities' => '',
    'Activity' => '',
    'Activity content ID' => '',
    'Administrative Users' => '',
    'Always' => '',
    'Authors' => '',
    'By creation date' => '',
    'By last update' => '',
    'Container' => '',
    'Content filters' => '',
    'Determine which Spaces should be taken into account.' => '',
    'Enter post content ID' => '',
    'Go Back' => '',
    'Import' => '',
    'Include all Spaces except selected' => '',
    'Include selected Spaces only' => '',
    'Layout' => '',
    'Leave empty to list all records related to the current user.' => '',
    'Limit' => '',
    'Logged-In Users' => '',
    'Manage layouts, snippet layouts, and containers. Layouts define page structures, snippet layouts are used in sidebars or sections, and containers are reusable content blocks.' => '',
    'Non-Logged-In Users' => '',
    'Resources' => '',
    'Restrict to following comma separated content IDs' => '',
    'Sorting' => '',
    'Space selection' => '',
    'Start Page' => '',
];
